summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorRobert Loehning <robert.loehning@qt.io>2018-10-22 16:34:31 +0200
committerRobert Loehning <robert.loehning@qt.io>2018-10-23 09:30:20 +0000
commit4032f6383a411768ddf6e6059aaed6c552fb65da (patch)
treee485758f1f508e8309a53b83090c6023988cd5b4 /src
parent7ae7f921aba238c0dc195c2c3dbd934e4e609f9d (diff)
downloadqt-creator-4032f6383a411768ddf6e6059aaed6c552fb65da.tar.gz
Fix frequent typo
can not -> cannot Change-Id: Ie872ada1bc9b4ed64bffb667c2e44dbb13b4ad11 Reviewed-by: Leena Miettinen <riitta-leena.miettinen@qt.io>
Diffstat (limited to 'src')
-rw-r--r--src/app/main.cpp2
-rw-r--r--src/libs/qtcreatorcdbext/containers.cpp2
-rw-r--r--src/libs/qtcreatorcdbext/pycdbextmodule.cpp4
-rw-r--r--src/libs/sqlite/sqlitedatabasebackend.cpp2
-rw-r--r--src/plugins/android/androidconfigurations.cpp6
-rw-r--r--src/plugins/android/androidmanager.cpp2
-rw-r--r--src/plugins/android/androidrunnerworker.cpp2
-rw-r--r--src/plugins/android/androidsdkmanager.cpp4
-rw-r--r--src/plugins/android/androidsignaloperation.cpp4
-rw-r--r--src/plugins/cmakeprojectmanager/cmakekitinformation.cpp2
-rw-r--r--src/plugins/cmakeprojectmanager/cmakeproject.cpp6
-rw-r--r--src/plugins/coreplugin/idocument.cpp2
-rw-r--r--src/plugins/coreplugin/infobar.cpp2
-rw-r--r--src/plugins/debugger/cdb/cdbengine.cpp4
-rw-r--r--src/plugins/ios/iosbuildsettingswidget.cpp2
-rw-r--r--src/plugins/ios/simulatorcontrol.cpp6
-rw-r--r--src/plugins/projectexplorer/buildconfiguration.h2
-rw-r--r--src/plugins/projectexplorer/gcctoolchain.cpp2
-rw-r--r--src/plugins/projectexplorer/gnumakeparser.cpp2
-rw-r--r--src/plugins/projectexplorer/jsonwizard/jsonwizard.cpp2
-rw-r--r--src/plugins/projectexplorer/osparser.cpp2
-rw-r--r--src/plugins/projectexplorer/userfileaccessor.cpp2
-rw-r--r--src/plugins/qmldesigner/designercore/model/abstractproperty.cpp2
-rw-r--r--src/plugins/qmldesigner/switchsplittabwidget.cpp2
-rw-r--r--src/plugins/qtsupport/baseqtversion.cpp2
-rw-r--r--src/plugins/subversion/subversionclient.cpp2
-rw-r--r--src/tools/sdktool/addkitoperation.cpp2
27 files changed, 37 insertions, 37 deletions
diff --git a/src/app/main.cpp b/src/app/main.cpp
index 9c61cb323d..0400f523c3 100644
--- a/src/app/main.cpp
+++ b/src/app/main.cpp
@@ -185,7 +185,7 @@ static inline int askMsgSendFailed()
QMessageBox::Retry);
}
-// taken from utils/fileutils.cpp. We can not use utils here since that depends app_version.h.
+// taken from utils/fileutils.cpp. We cannot use utils here since that depends app_version.h.
static bool copyRecursively(const QString &srcFilePath,
const QString &tgtFilePath)
{
diff --git a/src/libs/qtcreatorcdbext/containers.cpp b/src/libs/qtcreatorcdbext/containers.cpp
index 7ea4a2ddaf..809259f04d 100644
--- a/src/libs/qtcreatorcdbext/containers.cpp
+++ b/src/libs/qtcreatorcdbext/containers.cpp
@@ -77,7 +77,7 @@ static inline std::string fixInnerType(const std::string &type,
std::string stripped
= SymbolGroupValue::stripConst(SymbolGroupValue::stripClassPrefixes(type));
- // Unfortunately the cdb can not handle the vc exclusiv 64 bit integer
+ // Unfortunately the cdb cannot handle the vc exclusiv 64 bit integer
// "__int64" but works fine with "int64", so we have to strip down "__"
const size_t __int64pos = stripped.find("__int64");
if (__int64pos != std::string::npos)
diff --git a/src/libs/qtcreatorcdbext/pycdbextmodule.cpp b/src/libs/qtcreatorcdbext/pycdbextmodule.cpp
index ef47f38368..fc55076ea6 100644
--- a/src/libs/qtcreatorcdbext/pycdbextmodule.cpp
+++ b/src/libs/qtcreatorcdbext/pycdbextmodule.cpp
@@ -352,7 +352,7 @@ static PyObject *cdbext_reportResult(PyObject *, PyObject *args)
static PyMethodDef cdbextMethods[] = {
{"parseAndEvaluate", cdbext_parseAndEvaluate, METH_VARARGS,
- "Returns value of expression or None if the expression can not be resolved"},
+ "Returns value of expression or None if the expression cannot be resolved"},
{"resolveSymbol", cdbext_resolveSymbol, METH_VARARGS,
"Returns a list of symbol names matching the given pattern"},
{"getNameByAddress", cdbext_getNameByAddress, METH_VARARGS,
@@ -360,7 +360,7 @@ static PyMethodDef cdbextMethods[] = {
{"getAddressByName", cdbext_getAddressByName, METH_VARARGS,
"Returns the address of the symbol with the given name"},
{"lookupType", cdbext_lookupType, METH_VARARGS,
- "Returns type object or None if the type can not be resolved"},
+ "Returns type object or None if the type cannot be resolved"},
{"listOfLocals", cdbext_listOfLocals, METH_VARARGS,
"Returns list of values that are currently in scope"},
{"listOfModules", cdbext_listOfModules, METH_NOARGS,
diff --git a/src/libs/sqlite/sqlitedatabasebackend.cpp b/src/libs/sqlite/sqlitedatabasebackend.cpp
index 0e088c549d..a42564aca5 100644
--- a/src/libs/sqlite/sqlitedatabasebackend.cpp
+++ b/src/libs/sqlite/sqlitedatabasebackend.cpp
@@ -241,7 +241,7 @@ void DatabaseBackend::cacheTextEncoding()
void DatabaseBackend::checkForOpenDatabaseWhichCanBeClosed()
{
if (m_databaseHandle == nullptr)
- throw DatabaseIsAlreadyClosed("SqliteDatabaseBackend::close: database is not open so it can not be closed.");
+ throw DatabaseIsAlreadyClosed("SqliteDatabaseBackend::close: database is not open so it cannot be closed.");
}
void DatabaseBackend::checkDatabaseClosing(int resultCode)
diff --git a/src/plugins/android/androidconfigurations.cpp b/src/plugins/android/androidconfigurations.cpp
index b342053644..3da456cf37 100644
--- a/src/plugins/android/androidconfigurations.cpp
+++ b/src/plugins/android/androidconfigurations.cpp
@@ -793,7 +793,7 @@ QVersionNumber AndroidConfig::ndkVersion() const
{
QVersionNumber version;
if (!m_ndkLocation.exists()) {
- qCDebug(avdConfigLog) << "Can not find ndk version. Check NDK path."
+ qCDebug(avdConfigLog) << "Cannot find ndk version. Check NDK path."
<< m_ndkLocation.toString();
return version;
}
@@ -826,11 +826,11 @@ QVersionNumber AndroidConfig::ndkVersion() const
version = QVersionNumber::fromString(QString("%1.%2.0").arg(major)
.arg((int)minor[0].toLatin1() - 97));
} else {
- qCDebug(avdConfigLog) << "Can not find ndk version. Can not parse RELEASE.TXT."
+ qCDebug(avdConfigLog) << "Cannot find ndk version. Cannot parse RELEASE.TXT."
<< content;
}
} else {
- qCDebug(avdConfigLog) << "Can not find ndk version." << errorString;
+ qCDebug(avdConfigLog) << "Cannot find ndk version." << errorString;
}
}
return version;
diff --git a/src/plugins/android/androidmanager.cpp b/src/plugins/android/androidmanager.cpp
index eb453c7476..2ce812d675 100644
--- a/src/plugins/android/androidmanager.cpp
+++ b/src/plugins/android/androidmanager.cpp
@@ -218,7 +218,7 @@ QString AndroidManager::activityName(ProjectExplorer::Target *target)
/*!
Returns the minimum Android API level set for the APK. Minimum API level
- of the kit is returned if the manifest file of the APK can not be found
+ of the kit is returned if the manifest file of the APK cannot be found
or parsed.
*/
int AndroidManager::minimumSDK(ProjectExplorer::Target *target)
diff --git a/src/plugins/android/androidrunnerworker.cpp b/src/plugins/android/androidrunnerworker.cpp
index 87e4a5c36d..78cc6ffcff 100644
--- a/src/plugins/android/androidrunnerworker.cpp
+++ b/src/plugins/android/androidrunnerworker.cpp
@@ -426,7 +426,7 @@ void AndroidRunnerWorker::asyncStartHelper()
runAdb({"shell", "run-as", m_packageName, "chmod", "a+x", packageDir});
if (m_gdbserverPath.isEmpty() || !uploadFile(m_gdbserverPath, "gdbserver")) {
- emit remoteProcessFinished(tr("Can not find/copy C++ debug server."));
+ emit remoteProcessFinished(tr("Cannot find/copy C++ debug server."));
return;
}
diff --git a/src/plugins/android/androidsdkmanager.cpp b/src/plugins/android/androidsdkmanager.cpp
index d293960b62..00f866d47e 100644
--- a/src/plugins/android/androidsdkmanager.cpp
+++ b/src/plugins/android/androidsdkmanager.cpp
@@ -627,7 +627,7 @@ AndroidSdkPackage *SdkManagerOutputParser::parsePlatform(const QStringList &data
if (parseAbstractData(packageData, data, 2, "Platform")) {
int apiLevel = platformNameToApiLevel(packageData.headerParts.at(1));
if (apiLevel == -1) {
- qCDebug(sdkManagerLog) << "Platform: Can not parse api level:"<< data;
+ qCDebug(sdkManagerLog) << "Platform: Cannot parse api level:"<< data;
return nullptr;
}
platform = new SdkPlatform(packageData.revision, data.at(0), apiLevel);
@@ -647,7 +647,7 @@ QPair<SystemImage *, int> SdkManagerOutputParser::parseSystemImage(const QString
if (parseAbstractData(packageData, data, 4, "System-image")) {
int apiLevel = platformNameToApiLevel(packageData.headerParts.at(1));
if (apiLevel == -1) {
- qCDebug(sdkManagerLog) << "System-image: Can not parse api level:"<< data;
+ qCDebug(sdkManagerLog) << "System-image: Cannot parse api level:"<< data;
return result;
}
auto image = new SystemImage(packageData.revision, data.at(0),
diff --git a/src/plugins/android/androidsignaloperation.cpp b/src/plugins/android/androidsignaloperation.cpp
index 382db6ca07..bb54b833ab 100644
--- a/src/plugins/android/androidsignaloperation.cpp
+++ b/src/plugins/android/androidsignaloperation.cpp
@@ -57,7 +57,7 @@ void Android::Internal::AndroidSignalOperation::adbFindRunAsFinished(int exitCod
m_errorMessage += QLatin1String(" adb process error: ") + adbError;
}
if (runAs.isEmpty() || !m_errorMessage.isEmpty()) {
- m_errorMessage = QLatin1String("Can not find User for process: ")
+ m_errorMessage = QLatin1String("Cannot find User for process: ")
+ QString::number(m_pid)
+ m_errorMessage;
m_state = Idle;
@@ -90,7 +90,7 @@ void Android::Internal::AndroidSignalOperation::adbKillFinished(int exitCode,
m_errorMessage = QString::fromLatin1(m_adbProcess->readAllStandardError());
}
if (!m_errorMessage.isEmpty()) {
- m_errorMessage = QLatin1String("Can not kill process: ") + QString::number(m_pid)
+ m_errorMessage = QLatin1String("Cannot kill process: ") + QString::number(m_pid)
+ m_errorMessage;
}
m_state = Idle;
diff --git a/src/plugins/cmakeprojectmanager/cmakekitinformation.cpp b/src/plugins/cmakeprojectmanager/cmakekitinformation.cpp
index 3646b066b5..d5757b5e6d 100644
--- a/src/plugins/cmakeprojectmanager/cmakekitinformation.cpp
+++ b/src/plugins/cmakeprojectmanager/cmakekitinformation.cpp
@@ -567,7 +567,7 @@ QList<Task> CMakeConfigurationKitInformation::validate(const Kit *k) const
Utils::FileName tcCPath;
Utils::FileName tcCxxPath;
foreach (const CMakeConfigItem &i, config) {
- // Do not use expand(QByteArray) as we can not be sure the input is latin1
+ // Do not use expand(QByteArray) as we cannot be sure the input is latin1
const Utils::FileName expandedValue
= Utils::FileName::fromString(k->macroExpander()->expand(QString::fromUtf8(i.value)));
if (i.key == CMAKE_QMAKE_KEY)
diff --git a/src/plugins/cmakeprojectmanager/cmakeproject.cpp b/src/plugins/cmakeprojectmanager/cmakeproject.cpp
index 598a0f7b4a..70a6bc19b5 100644
--- a/src/plugins/cmakeprojectmanager/cmakeproject.cpp
+++ b/src/plugins/cmakeprojectmanager/cmakeproject.cpp
@@ -170,7 +170,7 @@ CMakeProject::CMakeProject(const FileName &fileName) : Project(Constants::CMAKEM
if (senderBc && senderBc->isActive()) {
// The environment on our BC has changed:
- // * Error out if the reader updates, can not happen since all BCs share a target/kit.
+ // * Error out if the reader updates, cannot happen since all BCs share a target/kit.
// * run cmake without configuration arguments if the reader stays
m_buildDirManager.setParametersAndRequestParse(
BuildDirParameters(senderBc),
@@ -183,7 +183,7 @@ CMakeProject::CMakeProject(const FileName &fileName) : Project(Constants::CMAKEM
if (senderBc && senderBc->isActive() && senderBc == m_buildDirManager.buildConfiguration()) {
// The build directory of our BC has changed:
- // * Error out if the reader updates, can not happen since all BCs share a target/kit.
+ // * Error out if the reader updates, cannot happen since all BCs share a target/kit.
// * run cmake without configuration arguments if the reader stays
// If no configuration exists, then the arguments will get added automatically by
// the reader.
@@ -198,7 +198,7 @@ CMakeProject::CMakeProject(const FileName &fileName) : Project(Constants::CMAKEM
if (senderBc && senderBc->isActive() && senderBc == m_buildDirManager.buildConfiguration()) {
// The CMake configuration has changed on our BC:
- // * Error out if the reader updates, can not happen since all BCs share a target/kit.
+ // * Error out if the reader updates, cannot happen since all BCs share a target/kit.
// * run cmake with configuration arguments if the reader stays
m_buildDirManager.setParametersAndRequestParse(
BuildDirParameters(senderBc),
diff --git a/src/plugins/coreplugin/idocument.cpp b/src/plugins/coreplugin/idocument.cpp
index fefff6a701..e5a78b32d5 100644
--- a/src/plugins/coreplugin/idocument.cpp
+++ b/src/plugins/coreplugin/idocument.cpp
@@ -126,7 +126,7 @@ Id IDocument::id() const
* In that case, the contents of the auto save file should be loaded, the file name of the
* IDocument should be set to \a fileName, and the document state be set to modified.
* If the editor is opened from a regular file, \a fileName and \a realFileName are the same.
- * Use \a errorString to return an error message, if this document can not handle the
+ * Use \a errorString to return an error message, if this document cannot handle the
* file contents.
* Returns whether the file was opened and read successfully.
*/
diff --git a/src/plugins/coreplugin/infobar.cpp b/src/plugins/coreplugin/infobar.cpp
index 3ca512c554..53c0cc4abe 100644
--- a/src/plugins/coreplugin/infobar.cpp
+++ b/src/plugins/coreplugin/infobar.cpp
@@ -111,7 +111,7 @@ void InfoBar::suppressInfo(Id id)
m_suppressed << id;
}
-// Info can not be added more than once, or if it is suppressed
+// Info cannot be added more than once, or if it is suppressed
bool InfoBar::canInfoBeAdded(Id id) const
{
return !containsInfo(id) && !m_suppressed.contains(id) && !globallySuppressed.contains(id);
diff --git a/src/plugins/ios/iosbuildsettingswidget.cpp b/src/plugins/ios/iosbuildsettingswidget.cpp
index 8b417ab390..f7c90b3aa9 100644
--- a/src/plugins/ios/iosbuildsettingswidget.cpp
+++ b/src/plugins/ios/iosbuildsettingswidget.cpp
@@ -126,7 +126,7 @@ void IosBuildSettingsWidget::setDefaultSigningIdentfier(const QString &identifie
} else {
// Reset to default
ui->m_signEntityCombo->setCurrentIndex(0);
- qCDebug(iosSettingsLog) << "Can not find default"
+ qCDebug(iosSettingsLog) << "Cannot find default"
<< (ui->m_autoSignCheckbox->isChecked() ? "team": "provisioning profile")
<< ". Identifier: " << identifier;
}
diff --git a/src/plugins/ios/simulatorcontrol.cpp b/src/plugins/ios/simulatorcontrol.cpp
index f3f048d02e..ebe9ece83f 100644
--- a/src/plugins/ios/simulatorcontrol.cpp
+++ b/src/plugins/ios/simulatorcontrol.cpp
@@ -107,7 +107,7 @@ static bool launchSimulator(const QString &simUdid) {
return runSimCtlCommand(QStringList({"boot", simUdid}), nullptr);
}
} else {
- qCDebug(simulatorLog) << "Can not start Simulator device."
+ qCDebug(simulatorLog) << "Cannot start Simulator device."
<< "Error probing Simulator.app instance";
return false;
}
@@ -438,7 +438,7 @@ void SimulatorControlPrivate::startSimulator(QFutureInterface<SimulatorControl::
}
if (simInfo.isShuttingDown()) {
- qCDebug(simulatorLog) << "Can not start Simulator device. "
+ qCDebug(simulatorLog) << "Cannot start Simulator device. "
<< "Previous instance taking too long to shutdown." << simInfo;
return;
}
@@ -465,7 +465,7 @@ void SimulatorControlPrivate::startSimulator(QFutureInterface<SimulatorControl::
qCDebug(simulatorLog) << "Error starting simulator.";
}
} else {
- qCDebug(simulatorLog) << "Can not start Simulator device. Simulator not in shutdown state."
+ qCDebug(simulatorLog) << "Cannot start Simulator device. Simulator not in shutdown state."
<< simInfo;
}
diff --git a/src/plugins/projectexplorer/buildconfiguration.h b/src/plugins/projectexplorer/buildconfiguration.h
index a368fe4909..95161bd6d7 100644
--- a/src/plugins/projectexplorer/buildconfiguration.h
+++ b/src/plugins/projectexplorer/buildconfiguration.h
@@ -127,7 +127,7 @@ protected:
~IBuildConfigurationFactory() override;
public:
- // The priority is negative if this factory can not create anything for the target.
+ // The priority is negative if this factory cannot create anything for the target.
// It is 0 for the "default" factory that wants to handle the target.
// Add 100 for each specialization.
virtual int priority(const Target *parent) const;
diff --git a/src/plugins/projectexplorer/gcctoolchain.cpp b/src/plugins/projectexplorer/gcctoolchain.cpp
index 394d4a26ae..0f2060b840 100644
--- a/src/plugins/projectexplorer/gcctoolchain.cpp
+++ b/src/plugins/projectexplorer/gcctoolchain.cpp
@@ -360,7 +360,7 @@ static Utils::FileName findLocalCompiler(const Utils::FileName &compilerPath,
// Find the "real" compiler if icecc, distcc or similar are in use. Ignore ccache, since that
// is local already.
- // Get the path to the compiler, ignoring direct calls to icecc and distcc as we can not
+ // Get the path to the compiler, ignoring direct calls to icecc and distcc as we cannot
// do anything about those.
const Utils::FileName compilerDir = compilerPath.parentDir();
const QString compilerDirString = compilerDir.toString();
diff --git a/src/plugins/projectexplorer/gnumakeparser.cpp b/src/plugins/projectexplorer/gnumakeparser.cpp
index 92c49a020a..2b9c0820cc 100644
--- a/src/plugins/projectexplorer/gnumakeparser.cpp
+++ b/src/plugins/projectexplorer/gnumakeparser.cpp
@@ -180,7 +180,7 @@ void GnuMakeParser::taskAdded(const Task &task, int linkedLines, int skippedLine
if (possibleFiles.size() == 1)
editable.file = Utils::FileName(possibleFiles.first());
// Let the Makestep apply additional heuristics (based on
- // files in ther project) if we can not uniquely
+ // files in ther project) if we cannot uniquely
// identify the file!
}
diff --git a/src/plugins/projectexplorer/jsonwizard/jsonwizard.cpp b/src/plugins/projectexplorer/jsonwizard/jsonwizard.cpp
index 894fadcfa4..fb0de4a329 100644
--- a/src/plugins/projectexplorer/jsonwizard/jsonwizard.cpp
+++ b/src/plugins/projectexplorer/jsonwizard/jsonwizard.cpp
@@ -181,7 +181,7 @@ QVariant JsonWizard::value(const QString &n) const
if (v.isValid())
return v;
if (hasField(n))
- return field(n); // Can not contain macros!
+ return field(n); // Cannot contain macros!
return QVariant();
}
diff --git a/src/plugins/projectexplorer/osparser.cpp b/src/plugins/projectexplorer/osparser.cpp
index acd4d3d633..d492d72f80 100644
--- a/src/plugins/projectexplorer/osparser.cpp
+++ b/src/plugins/projectexplorer/osparser.cpp
@@ -52,7 +52,7 @@ void OsParser::stdOutput(const QString &line)
if (Utils::HostOsInfo::isWindowsHost()) {
const QString trimmed = line.trimmed();
if (trimmed == QLatin1String("The process cannot access the file because it is being used by another process.")) {
- addTask(Task(Task::Error, tr("The process can not access the file because it is being used by another process.\n"
+ addTask(Task(Task::Error, tr("The process cannot access the file because it is being used by another process.\n"
"Please close all running instances of your application before starting a build."),
Utils::FileName(), -1, Constants::TASK_CATEGORY_COMPILE));
m_hasFatalError = true;
diff --git a/src/plugins/projectexplorer/userfileaccessor.cpp b/src/plugins/projectexplorer/userfileaccessor.cpp
index e47e9a2dc7..6776484506 100644
--- a/src/plugins/projectexplorer/userfileaccessor.cpp
+++ b/src/plugins/projectexplorer/userfileaccessor.cpp
@@ -398,7 +398,7 @@ QVariantMap UserFileAccessor::preprocessReadSettings(const QVariantMap &data) co
QVariantMap tmp = MergingSettingsAccessor::preprocessReadSettings(data);
// Move from old Version field to new one:
- // This can not be done in a normal upgrader since the version information is needed
+ // This cannot be done in a normal upgrader since the version information is needed
// to decide which upgraders to run
const QString obsoleteKey = OBSOLETE_VERSION_KEY;
const int obsoleteVersion = tmp.value(obsoleteKey, -1).toInt();
diff --git a/src/plugins/qmldesigner/designercore/model/abstractproperty.cpp b/src/plugins/qmldesigner/designercore/model/abstractproperty.cpp
index c6602a3bc7..9494334921 100644
--- a/src/plugins/qmldesigner/designercore/model/abstractproperty.cpp
+++ b/src/plugins/qmldesigner/designercore/model/abstractproperty.cpp
@@ -58,7 +58,7 @@ AbstractProperty::AbstractProperty(const PropertyName &propertyName, const Inter
m_view(view)
{
Q_ASSERT(!m_model || m_view);
- Q_ASSERT_X(!m_propertyName.contains(' '), Q_FUNC_INFO, "a property name can not contain a space");
+ Q_ASSERT_X(!m_propertyName.contains(' '), Q_FUNC_INFO, "a property name cannot contain a space");
}
AbstractProperty::AbstractProperty(const Internal::InternalPropertyPointer &property, Model* model, AbstractView *view)
diff --git a/src/plugins/qmldesigner/switchsplittabwidget.cpp b/src/plugins/qmldesigner/switchsplittabwidget.cpp
index 9d81f3564d..7dea80f164 100644
--- a/src/plugins/qmldesigner/switchsplittabwidget.cpp
+++ b/src/plugins/qmldesigner/switchsplittabwidget.cpp
@@ -122,7 +122,7 @@ QWidget *SwitchSplitTabWidget::currentWidget() const
void SwitchSplitTabWidget::updateSplitterSizes(int index)
{
if (isHidden()) {
- // we can not get the sizes if the splitter is hidden
+ // we cannot get the sizes if the splitter is hidden
m_splittSizesAreDirty = true;
return;
}
diff --git a/src/plugins/qtsupport/baseqtversion.cpp b/src/plugins/qtsupport/baseqtversion.cpp
index 553a3d6984..166e8a45ec 100644
--- a/src/plugins/qtsupport/baseqtversion.cpp
+++ b/src/plugins/qtsupport/baseqtversion.cpp
@@ -1807,7 +1807,7 @@ FileNameList BaseQtVersion::qtCorePaths() const
}
}
}
- // Only handle static libs if we can not find dynamic ones:
+ // Only handle static libs if we cannot find dynamic ones:
if (dynamicLibs.isEmpty())
return staticLibs;
return dynamicLibs;
diff --git a/src/plugins/subversion/subversionclient.cpp b/src/plugins/subversion/subversionclient.cpp
index e5b0a35640..a2e887239c 100644
--- a/src/plugins/subversion/subversionclient.cpp
+++ b/src/plugins/subversion/subversionclient.cpp
@@ -198,7 +198,7 @@ SubversionDiffEditorController::SubversionDiffEditorController(
: VcsBaseDiffEditorController(document, SubversionPlugin::instance()->client(), workingDirectory)
, m_state(Idle)
{
- forceContextLineCount(3); // SVN can not change that when using internal diff
+ forceContextLineCount(3); // SVN cannot change that when using internal diff
}
void SubversionDiffEditorController::setFilesList(const QStringList &filesList)
diff --git a/src/tools/sdktool/addkitoperation.cpp b/src/tools/sdktool/addkitoperation.cpp
index a58e1257c2..b1c480811e 100644
--- a/src/tools/sdktool/addkitoperation.cpp
+++ b/src/tools/sdktool/addkitoperation.cpp
@@ -280,7 +280,7 @@ bool AddKitOperation::setArguments(const QStringList &args)
if (m_deviceType.isEmpty())
std::cerr << "No devicetype given for kit." << std::endl << std::endl;
if (!m_debuggerId.isEmpty() && (!m_debugger.isEmpty() || m_debuggerEngine != 0)) {
- std::cerr << "Can not set both debugger id and debugger/debuggerengine." << std::endl << std::endl;
+ std::cerr << "Cannot set both debugger id and debugger/debuggerengine." << std::endl << std::endl;
return false;
}
diff --git a/src/plugins/debugger/cdb/cdbengine.cpp b/src/plugins/debugger/cdb/cdbengine.cpp
index 96206aa721..d8b99bc934 100644
--- a/src/plugins/debugger/cdb/cdbengine.cpp
+++ b/src/plugins/debugger/cdb/cdbengine.cpp
@@ -610,7 +610,7 @@ void CdbEngine::runEngine()
const auto cb = [this](const DebuggerResponse &r) { handleBreakInsert(r, Breakpoint()); };
if (boolSetting(CdbBreakOnCrtDbgReport)) {
Abi::OSFlavor flavor = runParameters().toolChainAbi.osFlavor();
// CrtDebugReport can not be safely resolved for vc 19
if ((flavor > Abi::WindowsMsvc2005Flavor && flavor <= Abi::WindowsMsvc2013Flavor) ||
flavor > Abi::WindowsMSysFlavor || flavor <= Abi::WindowsCEFlavor) {
const QString module = msvcRunTime(flavor);
@@ -2748,7 +2748,7 @@ void CdbEngine::setupScripting(const DebuggerResponse &response)
}
if (!ok) {
m_pythonVersion = 0;
- showMessage(QString("Can not parse sys.version:\n%1").arg(verOutput), LogWarning);
+ showMessage(QString("Cannot parse sys.version:\n%1").arg(verOutput), LogWarning);
return;
}
@@ -610,7 +610,7 @@ void CdbEngine::runEngine()
if (boolSetting(CdbBreakOnCrtDbgReport)) {
Abi::OSFlavor flavor = runParameters().toolChainAbi.osFlavor();
- // CrtDebugReport can not be safely resolved for vc 19
+ // CrtDebugReport cannot be safely resolved for vc 19
if ((flavor > Abi::WindowsMsvc2005Flavor && flavor <= Abi::WindowsMsvc2013Flavor) ||
flavor > Abi::WindowsMSysFlavor || flavor <= Abi::WindowsCEFlavor) {